# plutil

plutil is an [open source](https://github.com/pyqgis/plutil.git),
MIT licensed library useful for writing QGis plugins.

[![Build Status](https://travis-ci.org/H/plutil.svg?branch=master)](https://travis-ci.org/pyqgis/plutil)
[![Documentation Status](https://readthedocs.org/projects/plutil/badge/?version=latest)](https://plutil.readthedocs.io/en/latest/?badge=latest)


Install
-------

    pip install qgis-plutil

You can also download/clone the source, in which case you have to:

    git clone https://github.com/pyqgis/plutil.git
    python setup.py install
        
To contribute a patch clone the repo, create a new branch, install in
develop mode:
        
    python setup.py develop

